@@ -99,12 +99,8 @@ def rename(
         # if new_name exists... wow...
         _new_name = Path(path).dirname() / with_prefix + Path(path).stem + with_suffix
     elif with_suffix:
-        if new_name:
-            raise ValueError("You can just pass 'newname.suffix' to new_name ")
         _new_name = Path(path).with_suffix(with_suffix)
     elif with_prefix:
-        if new_name:
-            raise ValueError("You can just pass 'prefix-newname.suffix' to new_name ")
         _new_name = Path(path).dirname() / with_prefix + Path(path).name
 
     else:
@@ -135,7 +131,7 @@ def _move_all(f_list: t.List[Path], dst: str):
     for f in f_list:
         f.move(dst)
 
-
+# 旧的，暂时不用
 # =============================== Zip archieves functions ===============================
 # ╭─────────────────────────────────────────────╮
 # │ >>>>>>> OldZip(files&dirs) functions <<<<<< │
