@@ -1,3 +1,4 @@
+from distutils.command.config import config
 import os
 
 # import json
@@ -28,16 +29,28 @@ FREE_MAP = {
     "pictrans": OCRPicTrans(api=PIC_TRAN),
 }
 
+YOUDAO_PARAM_KEY = t.Literal["from", "to"]
+YOUDAO_PARAM_VALUE = t.Literal['auto', 'zh-CHS', 'en', 'ja', 'ko', 'fr', 'es', 'pt', 
+'it', 'ru', 'vi', 'de', 'ar', 'id', 'af', 'bs', 'bg', 'yue', 'ca', 'hr', 'cs', 
+'da', 'nl', 'et', 'fj', 'fi', 'el', 'ht', 'he', 'hi', 'mww', 'hu', 'sw', 'tlh', 
+'lv', 'lt', 'ms', 'mt', 'no', 'fa', 'pl', 'otq', 'ro', 'sr-Cyrl', 'sr-Latn', 
+'sk', 'sl', 'sv', 'ty', 'th', 'to', 'tr', 'uk', 'ur', 'cy', 'yua', 'sq', 'am', 
+'hy', 'az', 'bn', 'eu', 'be', 'ceb', 'co', 'eo', 'tl', 'fy', 'gl', 'ka', 'gu', 
+'ha', 'haw', 'is', 'ig', 'ga', 'jw', 'kn', 'kk', 'km', 'ku', 'ky', 'lo', 'la', 
+'lb', 'mk', 'mg', 'ml', 'mi', 'mr', 'mn', 'my', 'ne', 'ny', 'ps', 'pa', 'sm', 
+'gd', 'st', 'sn', 'sd', 'si', 'so', 'su', 'tg', 'ta', 'te', 'uz', 'xh', 'yi', 
+'yo', 'zu']
 
-def post_builder(name, **kwd):
+def post_builder(name, config: t.Dict[YOUDAO_PARAM_KEY, YOUDAO_PARAM_VALUE] = None, **kwd):
     token = os.getenv("token") or os.getenv("XXX")
-    # token = "tYwB%2FcQm2vlyCP1oP%2FRujYKV%2FCtDngeO7RRo07QT7XGcEvbrs%2BuXh5XOk78v%2FGS9nXL4dRS37%2FYnMrfJkon%2FQMHchXft0jdhFkmt7us7Gvc%3D"
+ 
     if token:
         _token = {"token": token}
 
         def free_post(q, *args, **kwd) -> Result:
-
             _config = FREE_MAP[name]
+            if config is not None:
+                _config.CONFIG.update(config)        
             _query = {_config.Q: q}
             _params = P(
                 _type="json",
@@ -60,7 +73,9 @@ def post_builder(name, **kwd):
         from dao.api import Api
 
         api = Api()
-
+        if config is not None:
+            api.config_map[name].CONFIG.update(config)
+        # print(api.config_map[name].CONFIG)
         @api(name)
         def _post(q, *args, **kwd) -> Result:
 
@@ -72,8 +87,11 @@ def post_builder(name, **kwd):
 # =============================== Translate functions ===============================
 
 
-def trans_post(q: str, **kwargs) -> t.Union[Result, dict]:
-    trans_post = post_builder("trans")
+def trans_post(q: str, config: t.Dict[YOUDAO_PARAM_KEY, YOUDAO_PARAM_VALUE] = None, **kwargs) -> t.Union[Result, dict]:
+    # parameter initialization
+    if config is None:
+        config={"from":"auto", "to":"auto"}
+    trans_post = post_builder("trans",  config=config)
     res = trans_post(q)
     return {"res": res, **kwargs}
 
@@ -99,8 +117,8 @@ def trans_filter(res: Result, full=False):
     return d
 
 
-def translate(q: str, full: bool = False):
-    p = ProcManager(trans_post, pf(trans_filter, full=full))
+def translate(q: str, config: t.Dict[YOUDAO_PARAM_KEY, YOUDAO_PARAM_VALUE] = None, full: bool = False):
+    p = ProcManager(pf(trans_post, config=config), pf(trans_filter, full=full))
     return p(dict(q=q))
 
 
@@ -108,7 +126,8 @@ def simple_translate(q):
     if " " in q:
         raise ValueError("Only for word")
     res = translate(q, full=True)
-    return res["simple_translation"][0]
+    # In different source and target languages, the format of res is different
+    return res if isinstance(res, str) else res["simple_translation"][0]
 
 
 # ===============================  Pic to pic translate ===============================
